#!/usr/bin/env python
# coding: utf-8
# /*##########################################################################
#
# Copyright (c) 2016-2017 European Synchrotron Radiation Facility
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# ###########################################################################*/
"""Qt Hdf5 widget examples

.. note:: This module has a dependency on the `h5py <http://www.h5py.org/>`_
    library, which is not a mandatory dependency for `silx`. You might need
    to install it if you don't already have it.
"""

import logging

logging.basicConfig()
_logger = logging.getLogger("hdf5widget")
"""Module logger"""

import silx.gui.plot
from silx.gui import qt

try:
    import fabio
except ImportError:
    fabio = None

_file_cache = {}

if qt.BINDING == 'PySide':
    from PySide.QtTest import QTest
elif qt.BINDING == 'PyQt5':
    from PyQt5.QtTest import QTest
elif qt.BINDING == 'PyQt4':
    from PyQt4.QtTest import QTest
else:
    raise ImportError('Unsupported Qt bindings')


class FocusedWindow(qt.QMainWindow):

    def focusOutEvent(self, *args, **kwargs):
        print("Focus out")
        return qt.QMainWindow.focusOutEvent(self, *args, **kwargs)

    def event(self, event):
        if event.type() == qt.QEvent.WindowDeactivate:
            print("Disactivated")
        return qt.QMainWindow.event(self, event)


if __name__ == "__main__":
    app = qt.QApplication([])
    window = FocusedWindow()
    plot = silx.gui.plot.Plot1D()
    window.setCentralWidget(plot)
    print("Before moving")
    test = QTest.mouseMove(plot, pos=qt.QPoint(10, 10))
    print("Before moving out")
    test = QTest.mouseClick(plot, qt.Qt.LeftButton, pos=qt.QPoint(-20, -20))
    window.show()

    def toto():
        print(window, window.isActiveWindow())

    timer = qt.QTimer()
    timer.timeout.connect(toto)
    timer.start(1000)

    app.exec_()
